@@ -256,7 +256,7 @@ def process_data_timestamp(data):
     if is_float(data['timestamp']):
         try:
             data['timestamp'] = datetime.fromtimestamp(float(data['timestamp']))
-        except:
+        except Exception:
             logger.exception('Failed reading timestamp')
             del data['timestamp']
     elif not isinstance(data['timestamp'], datetime):
@@ -269,7 +269,7 @@ def process_data_timestamp(data):
             format += 'Z'
         try:
             data['timestamp'] = datetime.strptime(data['timestamp'], format)
-        except:
+        except Exception:
             raise InvalidTimestamp('Invalid value for timestamp: %r' % data['timestamp'])
 
     return data
@@ -291,8 +291,8 @@ def validate_data(project, data, client=None):
         except InvalidTimestamp:
             # Log the error, remove the timestamp, and continue
             logger.error('Client %r passed an invalid value for timestamp %r' % (
-                data['timestamp'],
                 client or '<unknown client>',
+                data['timestamp'],
             ))
             del data['timestamp']
 
