@@ -356,13 +356,45 @@ class ChartMixin(object):
 class GroupManager(BaseManager, ChartMixin):
     use_for_related_fields = True
 
+    def _get_views(self, event):
+        from sentry.models import View
+        from sentry.views import View as ViewHandler
+
+        views = set()
+        for viewhandler in ViewHandler.objects.all():
+            try:
+                if not viewhandler.should_store(event):
+                    continue
+
+                path = '%s.%s' % (viewhandler.__module__, viewhandler.__class__.__name__)
+
+                if not viewhandler.ref:
+                    viewhandler.ref = View.objects.get_or_create(
+                        _cache=True,
+                        path=path,
+                        defaults=dict(
+                            verbose_name=viewhandler.verbose_name,
+                            verbose_name_plural=viewhandler.verbose_name_plural,
+                        ),
+                    )[0]
+
+                views.add(viewhandler.ref)
+
+            except Exception, exc:
+                # TODO: should we mail admins when there are failures?
+                try:
+                    logger.exception(exc)
+                except Exception, exc:
+                    warnings.warn(exc)
+
+        return views
+
     @transaction.commit_on_success
     def from_kwargs(self, project, **kwargs):
         # TODO: this function is way too damn long and needs refactored
         # the inner imports also suck so let's try to move it away from
         # the objects manager
-        from sentry.models import Event, Project, View
-        from sentry.views import View as ViewHandler
+        from sentry.models import Event, Project
 
         project = Project.objects.get_from_cache(pk=project)
 
@@ -377,6 +409,7 @@ class GroupManager(BaseManager, ChartMixin):
         site = kwargs.pop('site', None)
         date = kwargs.pop('timestamp', None) or datetime.datetime.utcnow()
         checksum = kwargs.pop('checksum', None)
+        tags = kwargs.pop('tags', [])
 
         # We must convert date to local time so Django doesn't mess it up
         # based on TIME_ZONE
@@ -415,35 +448,10 @@ class GroupManager(BaseManager, ChartMixin):
             'time_spent_count': time_spent and 1 or 0,
         })
 
-        views = set()
-        for viewhandler in ViewHandler.objects.all():
-            try:
-                if not viewhandler.should_store(event):
-                    continue
-
-                path = '%s.%s' % (viewhandler.__module__, viewhandler.__class__.__name__)
-
-                if not viewhandler.ref:
-                    viewhandler.ref = View.objects.get_or_create(
-                        _cache=True,
-                        path=path,
-                        defaults=dict(
-                            verbose_name=viewhandler.verbose_name,
-                            verbose_name_plural=viewhandler.verbose_name_plural,
-                        ),
-                    )[0]
-
-                views.add(viewhandler.ref)
-
-            except Exception, exc:
-                # TODO: should we mail admins when there are failures?
-                try:
-                    logger.exception(exc)
-                except Exception, exc:
-                    warnings.warn(exc)
+        views = self._get_views(event)
 
         try:
-            group, is_new, is_sample = self._create_group(event, **group_kwargs)
+            group, is_new, is_sample = self._create_group(event, tags=tags, **group_kwargs)
         except Exception, exc:
             # TODO: should we mail admins when there are failures?
             try:
@@ -486,9 +494,8 @@ class GroupManager(BaseManager, ChartMixin):
 
         return event
 
-    def _create_group(self, event, **kwargs):
-        from sentry.models import ProjectCountByMinute, MessageCountByMinute, FilterValue, \
-          MessageFilterValue, STATUS_RESOLVED
+    def _create_group(self, event, tags=None, **kwargs):
+        from sentry.models import ProjectCountByMinute, MessageCountByMinute, STATUS_RESOLVED
 
         date = event.datetime
         time_spent = event.time_spent
@@ -537,6 +544,10 @@ class GroupManager(BaseManager, ChartMixin):
                     'active_at': date,
                     'status': 0,
                 })
+                group.status = 0
+                group.active_at = date
+
+            group.last_seen = max(event.datetime, group.last_seen)
 
             silence_timedelta = date - group.last_seen
             silence = silence_timedelta.days * 86400 + silence_timedelta.seconds
@@ -577,13 +588,24 @@ class GroupManager(BaseManager, ChartMixin):
             'date': normalized_datetime,
         })
 
-        # TODO: should we move this into a TagPlugin?
-        for key, value in (
-                ('logger', event.logger),
-            ):
-            if not value:
-                continue
+        if not tags:
+            tags = []
+        else:
+            tags = list(tags)
 
+        tags += [('logger', event.logger)]
+
+        self.add_tags(group, tags)
+
+        return group, is_new, is_sample
+
+    def add_tags(self, group, tags):
+        from sentry.models import FilterValue, MessageFilterValue
+
+        project = group.project
+        date = group.last_seen
+
+        for key, value in itertools.ifilter(bool, tags):
             FilterValue.objects.get_or_create(
                 project=project,
                 key=key,
@@ -601,8 +623,6 @@ class GroupManager(BaseManager, ChartMixin):
                 'last_seen': date,
             })
 
-        return group, is_new, is_sample
-
     def get_by_natural_key(self, logger, culprit, checksum):
         return self.get(logger=logger, view=culprit, checksum=checksum)
 
